@@ -1,7 +1,7 @@
 /* Binary relations.
 
-   Copyright (C) 2002, 2004-2005, 2009-2015 Free Software Foundation,
-   Inc.
+   Copyright (C) 2002, 2004-2005, 2009-2015, 2018 Free Software
+   Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
 
@@ -34,10 +34,10 @@ relation_print (relation r, relation_node size, FILE *out)
 
   for (i = 0; i < size; ++i)
     {
-      fprintf (out, "%3lu: ", (unsigned long int) i);
+      fprintf (out, "%3lu: ", (unsigned long) i);
       if (r[i])
         for (j = 0; r[i][j] != END_NODE; ++j)
-          fprintf (out, "%3lu ", (unsigned long int) r[i][j]);
+          fprintf (out, "%3lu ", (unsigned long) r[i][j]);
       fputc ('\n', out);
     }
   fputc ('\n', out);
